@@ -21,9 +21,7 @@ class ValueEvent:
     value = attr.ib(default=None, init=False)
 
     async def set(self, value):
-        """Set the internal flag value to True, and wake any waiting tasks.
-
-        """
+        """Set the internal flag value to True, and wake any waiting tasks."""
         self.value = outcome.Value(value)
         await self.event.set()
 
@@ -31,9 +29,7 @@ class ValueEvent:
         return self.value is not None
 
     async def set_error(self, exc):
-        """Set the internal flag value to True, and wake any waiting tasks.
-
-        """
+        """Set the internal flag value to True, and wake any waiting tasks."""
         self.value = outcome.Error(exc)
         await self.event.set()
 
